@@ -1,6 +1,6 @@
 package App::RecordStream::Aggregator::RecordForMinimum;
 
-our $VERSION = "4.0.17";
+our $VERSION = "4.0.20";
 
 use strict;
 use warnings;
@@ -49,7 +49,7 @@ sub reduce
   my ($v1, $r1) = @$cookie1;
   my ($v2, $r2) = @$cookie2;
 
-  if($v1 > $v2)
+  if($v1 < $v2)
   {
     return $cookie1;
   }
